<?php

namespace App\Http\Controllers;

use App\Http\Requests\CreateProductInPromoRequest;
use App\Http\Requests\UpdateProductInPromoRequest;
use App\Repositories\ProductInPromoRepository;
use App\Http\Controllers\AppBaseController;
use Illuminate\Http\Request;
use Flash;
use Response;

class ProductInPromoController extends AppBaseController
{
    /** @var  ProductInPromoRepository */
    private $productInPromoRepository;

    public function __construct(ProductInPromoRepository $productInPromoRepo)
    {
        $this->productInPromoRepository = $productInPromoRepo;
    }

    /**
     * Display a listing of the ProductInPromo.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function index(Request $request)
    {
        $productInPromos = $this->productInPromoRepository->paginate(25);

        return view('product_in_promos.index')
            ->with('productInPromos', $productInPromos);
    }

    /**
     * Show the form for creating a new ProductInPromo.
     *
     * @return Response
     */
    public function create()
    {
        return view('product_in_promos.create');
    }

    /**
     * Store a newly created ProductInPromo in storage.
     *
     * @param CreateProductInPromoRequest $request
     *
     * @return Response
     */
    public function store(CreateProductInPromoRequest $request)
    {
        $input = $request->all();

        $productInPromo = $this->productInPromoRepository->create($input);

        Flash::success('Product In Promo saved successfully.');

        return redirect(route('productInPromos.index'));
    }

    /**
     * Display the specified ProductInPromo.
     *
     * @param int $id
     *
     * @return Response
     */
    public function show($id)
    {
        $productInPromo = $this->productInPromoRepository->find($id);

        if (empty($productInPromo)) {
            Flash::error('Product In Promo not found');

            return redirect(route('productInPromos.index'));
        }

        return view('product_in_promos.show')->with('productInPromo', $productInPromo);
    }

    /**
     * Show the form for editing the specified ProductInPromo.
     *
     * @param int $id
     *
     * @return Response
     */
    public function edit($id)
    {
        $productInPromo = $this->productInPromoRepository->find($id);

        if (empty($productInPromo)) {
            Flash::error('Product In Promo not found');

            return redirect(route('productInPromos.index'));
        }

        return view('product_in_promos.edit')->with('productInPromo', $productInPromo);
    }

    /**
     * Update the specified ProductInPromo in storage.
     *
     * @param int $id
     * @param UpdateProductInPromoRequest $request
     *
     * @return Response
     */
    public function update($id, UpdateProductInPromoRequest $request)
    {
        $productInPromo = $this->productInPromoRepository->find($id);

        if (empty($productInPromo)) {
            Flash::error('Product In Promo not found');

            return redirect(route('productInPromos.index'));
        }

        $productInPromo = $this->productInPromoRepository->update($request->all(), $id);

        Flash::success('Product In Promo updated successfully.');

        return redirect(route('productInPromos.index'));
    }

    /**
     * Remove the specified ProductInPromo from storage.
     *
     * @param int $id
     *
     * @throws \Exception
     *
     * @return Response
     */
    public function destroy($id)
    {
        $productInPromo = $this->productInPromoRepository->find($id);

        if (empty($productInPromo)) {
            Flash::error('Product In Promo not found');

            return redirect(route('productInPromos.index'));
        }

        $this->productInPromoRepository->delete($id);

        Flash::success('Product In Promo deleted successfully.');

        return redirect(route('productInPromos.index'));
    }
}
