<?php

namespace App\Http\Controllers;

use App\Http\Requests\CreateSendSmsCmrRequest;
use App\Http\Requests\UpdateSendSmsCmrRequest;
use App\Repositories\SendSmsCmrRepository;
use App\Http\Controllers\AppBaseController;
use Illuminate\Http\Request;
use Flash;
use Response;

class SendSmsCmrController extends AppBaseController
{
    /** @var  SendSmsCmrRepository */
    private $sendSmsCmrRepository;

    public function __construct(SendSmsCmrRepository $sendSmsCmrRepo)
    {
        $this->sendSmsCmrRepository = $sendSmsCmrRepo;
    }

    /**
     * Display a listing of the SendSmsCmr.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function index(Request $request)
    {
        $sendSmsCmrs = $this->sendSmsCmrRepository->paginate(25);

        return view('send_sms_cmrs.index')
            ->with('sendSmsCmrs', $sendSmsCmrs);
    }

    /**
     * Show the form for creating a new SendSmsCmr.
     *
     * @return Response
     */
    public function create()
    {
        return view('send_sms_cmrs.create');
    }

    /**
     * Store a newly created SendSmsCmr in storage.
     *
     * @param CreateSendSmsCmrRequest $request
     *
     * @return Response
     */
    public function store(CreateSendSmsCmrRequest $request)
    {
        $input = $request->all();

        $sendSmsCmr = $this->sendSmsCmrRepository->create($input);

        Flash::success('Send Sms Cmr saved successfully.');

        return redirect(route('sendSmsCmrs.index'));
    }

    /**
     * Display the specified SendSmsCmr.
     *
     * @param int $id
     *
     * @return Response
     */
    public function show($id)
    {
        $sendSmsCmr = $this->sendSmsCmrRepository->find($id);

        if (empty($sendSmsCmr)) {
            Flash::error('Send Sms Cmr not found');

            return redirect(route('sendSmsCmrs.index'));
        }

        return view('send_sms_cmrs.show')->with('sendSmsCmr', $sendSmsCmr);
    }

    /**
     * Show the form for editing the specified SendSmsCmr.
     *
     * @param int $id
     *
     * @return Response
     */
    public function edit($id)
    {
        $sendSmsCmr = $this->sendSmsCmrRepository->find($id);

        if (empty($sendSmsCmr)) {
            Flash::error('Send Sms Cmr not found');

            return redirect(route('sendSmsCmrs.index'));
        }

        return view('send_sms_cmrs.edit')->with('sendSmsCmr', $sendSmsCmr);
    }

    /**
     * Update the specified SendSmsCmr in storage.
     *
     * @param int $id
     * @param UpdateSendSmsCmrRequest $request
     *
     * @return Response
     */
    public function update($id, UpdateSendSmsCmrRequest $request)
    {
        $sendSmsCmr = $this->sendSmsCmrRepository->find($id);

        if (empty($sendSmsCmr)) {
            Flash::error('Send Sms Cmr not found');

            return redirect(route('sendSmsCmrs.index'));
        }

        $sendSmsCmr = $this->sendSmsCmrRepository->update($request->all(), $id);

        Flash::success('Send Sms Cmr updated successfully.');

        return redirect(route('sendSmsCmrs.index'));
    }

    /**
     * Remove the specified SendSmsCmr from storage.
     *
     * @param int $id
     *
     * @throws \Exception
     *
     * @return Response
     */
    public function destroy($id)
    {
        $sendSmsCmr = $this->sendSmsCmrRepository->find($id);

        if (empty($sendSmsCmr)) {
            Flash::error('Send Sms Cmr not found');

            return redirect(route('sendSmsCmrs.index'));
        }

        $this->sendSmsCmrRepository->delete($id);

        Flash::success('Send Sms Cmr deleted successfully.');

        return redirect(route('sendSmsCmrs.index'));
    }
}
