<?php namespace Tests\Repositories;

use App\Models\SendSmsCmr;
use App\Repositories\SendSmsCmrRepository;
use Illuminate\Foundation\Testing\DatabaseTransactions;
use Tests\TestCase;
use Tests\ApiTestTrait;

class SendSmsCmrRepositoryTest extends TestCase
{
    use ApiTestTrait, DatabaseTransactions;

    /**
     * @var SendSmsCmrRepository
     */
    protected $sendSmsCmrRepo;

    public function setUp() : void
    {
        parent::setUp();
        $this->sendSmsCmrRepo = \App::make(SendSmsCmrRepository::class);
    }

    /**
     * @test create
     */
    public function test_create_send_sms_cmr()
    {
        $sendSmsCmr = SendSmsCmr::factory()->make()->toArray();

        $createdSendSmsCmr = $this->sendSmsCmrRepo->create($sendSmsCmr);

        $createdSendSmsCmr = $createdSendSmsCmr->toArray();
        $this->assertArrayHasKey('id', $createdSendSmsCmr);
        $this->assertNotNull($createdSendSmsCmr['id'], 'Created SendSmsCmr must have id specified');
        $this->assertNotNull(SendSmsCmr::find($createdSendSmsCmr['id']), 'SendSmsCmr with given id must be in DB');
        $this->assertModelData($sendSmsCmr, $createdSendSmsCmr);
    }

    /**
     * @test read
     */
    public function test_read_send_sms_cmr()
    {
        $sendSmsCmr = SendSmsCmr::factory()->create();

        $dbSendSmsCmr = $this->sendSmsCmrRepo->find($sendSmsCmr->id);

        $dbSendSmsCmr = $dbSendSmsCmr->toArray();
        $this->assertModelData($sendSmsCmr->toArray(), $dbSendSmsCmr);
    }

    /**
     * @test update
     */
    public function test_update_send_sms_cmr()
    {
        $sendSmsCmr = SendSmsCmr::factory()->create();
        $fakeSendSmsCmr = SendSmsCmr::factory()->make()->toArray();

        $updatedSendSmsCmr = $this->sendSmsCmrRepo->update($fakeSendSmsCmr, $sendSmsCmr->id);

        $this->assertModelData($fakeSendSmsCmr, $updatedSendSmsCmr->toArray());
        $dbSendSmsCmr = $this->sendSmsCmrRepo->find($sendSmsCmr->id);
        $this->assertModelData($fakeSendSmsCmr, $dbSendSmsCmr->toArray());
    }

    /**
     * @test delete
     */
    public function test_delete_send_sms_cmr()
    {
        $sendSmsCmr = SendSmsCmr::factory()->create();

        $resp = $this->sendSmsCmrRepo->delete($sendSmsCmr->id);

        $this->assertTrue($resp);
        $this->assertNull(SendSmsCmr::find($sendSmsCmr->id), 'SendSmsCmr should not exist in DB');
    }
}
